All of lore.kernel.org
 help / color / mirror / Atom feed
From: SeongJae Park <sj@kernel.org>
To: sashiko@lists.linux.dev
Cc: SeongJae Park <sj@kernel.org>
Subject: Using mm.git or damon/next for DAMON patch baselines
Date: Sat, 25 Apr 2026 15:16:29 -0700	[thread overview]
Message-ID: <20260425221630.81644-1-sj@kernel.org> (raw)

Hello Sashiko team,


DAMON patches are usually based on a commit of damon/next [1] that based on
mm-new.  So the baseline commit that added by git on the patch should be
available on damon/next.  Or, mm-new should almost always the right choice for
the baseline.

But seems Sashiko is not aware of [2] that, and therefore sometimes fais
reviews at patch applying step.  Could we make Sashiko to use mm trees or the
baseline commit on damon/next tree?

I was thinking changes like below might work, but I don't know how to
read/write/test Rust code...  I also have no idea about how I can make Sashiko
to try finding the baseline commit from damon/next tree.  So just asking here.

'''
diff --git a/src/baseline.rs b/src/baseline.rs
index 5eb3303..c3dc628 100644
--- a/src/baseline.rs
+++ b/src/baseline.rs
@@ -317,10 +317,12 @@ impl BaselineRegistry {
         candidates.sort_by(|a, b| b.1.cmp(a.1).then_with(|| a.0.0.cmp(&b.0.0)));

         // Check for Linux-MM special handling
         // If the top candidate is akpm/mm or linux-mm, OR the subsystem is MEMORY MANAGEMENT
         let (top_url, _top_branch) = candidates[0].0;
         let is_mm = top_url.contains("akpm/mm")
             || top_url.contains("linux-mm")
+            || top_url.contains("damon")
             || matched_subsystem_name
                 .as_deref()
                 .map(|s| s.eq_ignore_ascii_case("MEMORY MANAGEMENT"))
@@ -317,10 +317,12 @@ impl BaselineRegistry {

         // Check for Linux-MM special handling
-        // If the top candidate is akpm/mm or linux-mm, OR the subsystem is MEMORY MANAGEMENT
+        // If the top candidate is akpm/mm or linux-mm or damon, OR the
+        // subsystem is MEMORY MANAGEMENT
         let (top_url, _top_branch) = candidates[0].0;
         let is_mm = top_url.contains("akpm/mm")
'''

[1] https://origin.kernel.org/doc/html/latest/mm/damon/maintainer-profile.html#scm-trees
[2] https://sashiko.dev/#/patchset/20260425203309.108879-1-sj%40kernel.org


Thanks,
SJ

                 reply	other threads:[~2026-04-25 22:16 UTC|newest]

Thread overview: [no followups] expand[flat|nested]  mbox.gz  Atom feed

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20260425221630.81644-1-sj@kernel.org \
    --to=sj@kernel.org \
    --cc=sashiko@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is an external index of several public inboxes,
see mirroring instructions on how to clone and mirror
all data and code used by this external index.